---
title: La signature électronique dans Chill

theme: night

css:
  - https://www.unpkg.com/fork-awesome@1.2.0/css/fork-awesome.min.css
  - ./styles.css

---

# Signature électronique dans Chill

## Sommaire

1. Nouveautés relatives à la gestion des documents
2. Nouveautés relatives aux workflows
3. Processus de signature
4. Processus d'envoi externes de documents

# Gestion des documents: nouveautés

## Historique des documents

- À chaque modification d'un document, Chill conserve les anciennes versions;
- Les anciennes versions sont conservées pendant 90 jours.

----

![Historique d'un document](./img/short-history-of-a-document.png)

----

Il est possible de:

- restaurer un document à une version antérieure;
- télécharger le document depuis une ancienne version;

## Droits sur les documents associés à un workflow

---

Pour les documents associés à un workflow:

- le document est en **lecture seule** pour tous;
- **édition possible** par: les utilisateurs qui peuvent appliquer une étape du workflow;
- **workflow finalisé** ? Le document est en lecture seule.

## Duplication de document

Il est possible de dupliquer un document:

- dans les évaluations (actions d'accompagnement);
- dans les parcours.

Cela permet de restaurer un document qui serait figé par un workflow.

# Workflows: nouveautés

## Annulation automatique des workflows

- workflows non finalisés;
- sans intervention d'un agent…
- …pendant 90 jours

## Suppression des workflows annulés

Il est possible de supprimer les workflows annulés (à partir de mi-novembre)

## Mettre en attente un workflow

Pour indiquer aux collègues que:

- le workflow est vu;
- mais pas encore traité.

Aucun impact sur la gestion des workflows.

----

La "mise en attente" ne bloque pas l'annulation automatique après 90 jours.

----

![Exemple de mise en attente](./img/mise-en-attente-workflow-display.png)

## Maximum :one: workflow par entité

On ne peut pas créer plusieurs workflows sur un même document.

## Envoi du workflow à des adresses emails 📨
<!-- ici, très spécifique à vendée -->
Adresse email manuelles: supprimée

Remplacé par l'adresse email des MDSF

-----

## Adresse email MDSF

- 🆕 Nommées "Groupes utilisateurs";
- Chaque groupe est associé à :one: adresse email;

-----

- Possibilité d'associer les agents aux groupes
- droits automatiques, comme si on listait tous les agents d'un groupe

(pas utilisé par le CD85 au lancement)

## Envoi du workflow à…

- des utilisateurs;
- et/ou des groupes d'utilisateurs;

Même interface de recherche.


# Signature électronique des documents

## Principe de la signature

Défini par Règlement UE "Eidas"

- **non-modification du document** après chaque signature;
- appose une **date certaine** sur le document;
- identification du signataire;

De manière électronique.

----

## Identification du signataire

Constitue un "dossier de preuve" pour la signature:

- document d'identité pour l'usager;
- récolte de l'adresse IP, agent signant, etc;

----

**Esprit:** apposer une signature simplement.

ℹ️ Pas de dou️ble vérification de l'identité avec envoi de SMS, etc.

## Associé au workflow

Pour apposer une signature:

- un document est présent dans Chill;
- workflow sur ce document;
- étape `Demande de signature`.

## Uniquement documents PDF

- Standard pour l'archivage;
- Le document est converti automatiquement
  
  Depuis `docx`, `odt`, …

- L'ancienne version (modifiable) est conservée;

  Elle n'est donc pas supprimée après 90 jours

## Zones de signatures

Des zones de signatures vont être ajoutées sur les documents.

![Document avec zones de signature](./img/doc-with-zone-signature.png)

----

Possibilité d'ajouter des zones manuellement

## Signature des agents

- :one: seul agent par demande de signature
- seul l'agent peut signer

## Signature des usagers

- signature de un ou plusieurs usagers par étape

  Ex.: un couple, les parents, …

----

**Tout le monde** peut appliquer la signature d'un usager

Le workflow est visible par tous.

----

![Rappel des signatures résultats de recherche](./img/rappel-signature-resultats-recherche.png)

----

### Pour chaque signature, demande de …

- type de document d'identité;
- numéro de document;
- date d'expiration du document. 

----

![Demande de document d'identité](./img/signature-ask-documents.png)

----

### Possibilité de signer plus tard

_L'usager n'a pas sa carte d'identité, il n'est pas présent, …_

L'usager peut revenir signer à l'accueil avec une tablette.


## _Et si on ne veut pas signer ?_

Indiquer si:

- signature annulée;
- signature rejetée.

## Après la signature ?

**Toutes** les signatures doivent être traitées:

<small>Tous les usagers doivent avoir signé</small>

Signature appliquée, rejetée, annulée, …

-----

### Signature des agents

- nouvelle étape `Signature traitée`
- l'agent qui **a signé** "reprend la main"
  
  (il peut donc appliquer la prochaine étape)

----

### Signature des usagers

- nouvelle étape `Signature traitée`
- l'agent qui a **demandé** la signature "reprend la main"

----

### :warning: 

Délai de quelques secondes après le traitement des signatures

<small>surtout visible après le rejet de la signature</small>

⌛ 3-5 secondes d'attente ⌛

## Qui a signé ?

Liste des signatures dans l'historique.

----

![List des signatures dans l'historique](img/liste-signature-appliquees.png)

# Manipulations ⛏️

## Accès

[https://chillformation.vendee.fr](chillformation.vendee.fr)

`formXX` ― 🔑 `ChillCD85!`

Emails: sur [https://yopmail.com](yopmail.com) ― 📬 `chillcd85`

## Tâches

Générer un document "courrier type" dans le parcours

Signer un document soi-même

-----

Faire signer un document à sa·son voisin·e de gauche, comme **utilisateur·trice**.

-----

Faire signer un document à sa·son voisin·e de droite, comme **usager**.

Convenir à deux du nom de l'usager. 

Le voisin de droite est l'usager.

# Envoi sécurisé des documents 📧

## Calendrier 🗓️

À partir de fin novembre 2024

## But

- Faire parvenir un document à un tiers;
- Respect du RGPD 🔐;

  (Le document ne transite pas par des boites emails non sécurisées)

## Fonctionnement

1. Le document fait l'objet d'un workflow;
2. Étape `Envoi sécurisé par courrier électronique`;
3. Lien sécurisé envoyé par email;
4. Le tiers consulte le document dans Chill;

  (Il·elle peut télécharger le document) 

----

5. Dès la première consultation, le workflow est finalisé automatiquement. 
6. Le tiers peut encore consulter le document pendant 30 jours;

## Sécurisation

- lien sécurisé, code unique;
- maximum 100 consultations (par tiers);
- traçage adresse IP et dates de consultation;
  
:warning: N'empêche pas un tiers de transférer l'email avec le lien.

## Envoi à qui ?

- à une adresse email;
- à un tiers (avec une adresse email enregistrée dans sa fiche);

----

Envoi en central: sera effectué par ce biais.

## Pièces jointes

(à partir de fin novembre)

- Possibilité d'ajouter des pièces jointes aux documents ➡️ plusieurs documents;
- Le tiers peut voir le document **et** les pièces jointes.


# Manipulations ⛏️

## Tâche

- envoyer un document à un tiers;
- récupérer le lien sur yopmail;
- consulter le document;
- vérifier la finalisation automatique du workflow.